@@ -11,8 +11,12 @@ func init() {
 	commands.Register(AttachKey{})
 }
 
+func (AttachKey) Description() string {
+	return "Attach the public key of the current account."
+}
+
 func (AttachKey) Context() commands.CommandContext {
-	return commands.COMPOSE
+	return commands.COMPOSE_EDIT | commands.COMPOSE_REVIEW
 }
 
 func (AttachKey) Aliases() []string {
