@@ -9,13 +9,17 @@ import (
 )
 
 type ChangeTab struct {
-	Tab string `opt:"tab" complete:"CompleteTab"`
+	Tab string `opt:"tab" complete:"CompleteTab" desc:"Tab name."`
 }
 
 func init() {
 	Register(ChangeTab{})
 }
 
+func (ChangeTab) Description() string {
+	return "Change the focus to the specified tab."
+}
+
 func (ChangeTab) Context() CommandContext {
 	return GLOBAL
 }
