@@ -1,17 +1,19 @@
 package config
 
 import (
-	"git.sr.ht/~rjarry/aerc/log"
+	"git.sr.ht/~rjarry/aerc/lib/log"
 	"github.com/go-ini/ini"
 )
 
 type HooksConfig struct {
 	AercStartup  string `ini:"aerc-startup"`
 	AercShutdown string `ini:"aerc-shutdown"`
+	FlagChanged  string `ini:"flag-changed"`
 	MailReceived string `ini:"mail-received"`
 	MailDeleted  string `ini:"mail-deleted"`
 	MailAdded    string `ini:"mail-added"`
 	MailSent     string `ini:"mail-sent"`
+	TagModified  string `ini:"tag-modified"`
 }
 
 var Hooks HooksConfig
