@@ -317,6 +317,8 @@ func (w *Worker) handleMessage(msg types.WorkerMessage) error {
 		return w.handleFlagMessages(msg)
 	case *types.AnsweredMessages:
 		return w.handleAnsweredMessages(msg)
+	case *types.ForwardedMessages:
+		return w.handleForwardedMessages(msg)
 	case *types.CopyMessages:
 		return w.handleCopyMessages(msg)
 	case *types.MoveMessages:
@@ -458,7 +460,7 @@ func (w *Worker) handleFetchDirectoryContents(
 	msg *types.FetchDirectoryContents,
 ) error {
 	var (
-		uids []uint32
+		uids []models.UID
 		err  error
 	)
 	if msg.Filter != nil {
@@ -492,7 +494,7 @@ func (w *Worker) handleFetchDirectoryContents(
 	return nil
 }
 
-func (w *Worker) sort(ctx context.Context, uids []uint32, criteria []*types.SortCriterion) ([]uint32, error) {
+func (w *Worker) sort(ctx context.Context, uids []models.UID, criteria []*types.SortCriterion) ([]models.UID, error) {
 	if len(criteria) == 0 {
 		// At least sort by uid, parallel searching can create random
 		// order
@@ -514,7 +516,7 @@ func (w *Worker) sort(ctx context.Context, uids []uint32, criteria []*types.Sort
 		default:
 			limit <- struct{}{}
 			wg.Add(1)
-			go func(uid uint32) {
+			go func(uid models.UID) {
 				defer log.PanicHandler()
 				defer wg.Done()
 				info, err := w.msgHeadersFromUid(uid)
@@ -544,7 +546,7 @@ func (w *Worker) handleFetchDirectoryThreaded(
 	msg *types.FetchDirectoryThreaded,
 ) error {
 	var (
-		uids []uint32
+		uids []models.UID
 		err  error
 	)
 	if msg.Filter != nil {
@@ -554,7 +556,7 @@ func (w *Worker) handleFetchDirectoryThreaded(
 		}
 	} else {
 		uids, err = w.c.UIDs(*w.selected)
-		if err != nil {
+		if err != nil && len(uids) == 0 {
 			w.worker.Errorf("failed scanning uids: %v", err)
 			return err
 		}
@@ -572,7 +574,7 @@ func (w *Worker) handleFetchDirectoryThreaded(
 	return nil
 }
 
-func (w *Worker) threads(ctx context.Context, uids []uint32,
+func (w *Worker) threads(ctx context.Context, uids []models.UID,
 	criteria []*types.SortCriterion,
 ) ([]*types.Thread, error) {
 	builder := aercLib.NewThreadBuilder(iterator.NewFactory(false), false)
@@ -588,7 +590,7 @@ func (w *Worker) threads(ctx context.Context, uids []uint32,
 		default:
 			limit <- struct{}{}
 			wg.Add(1)
-			go func(uid uint32) {
+			go func(uid models.UID) {
 				defer log.PanicHandler()
 				defer wg.Done()
 				info, err := w.msgHeadersFromUid(uid)
@@ -782,6 +784,27 @@ func (w *Worker) handleAnsweredMessages(msg *types.AnsweredMessages) error {
 	return nil
 }
 
+func (w *Worker) handleForwardedMessages(msg *types.ForwardedMessages) error {
+	for _, uid := range msg.Uids {
+		m, err := w.c.Message(*w.selected, uid)
+		if err != nil {
+			w.worker.Errorf("could not get message: %v", err)
+			w.err(msg, err)
+			continue
+		}
+		if err := m.MarkForwarded(msg.Forwarded); err != nil {
+			w.worker.Errorf("could not mark message as answered: %v", err)
+			w.err(msg, err)
+			continue
+		}
+
+		w.worker.PostMessage(&types.DirectoryInfo{
+			Info: w.getDirectoryInfo(w.selectedName),
+		}, nil)
+	}
+	return nil
+}
+
 func (w *Worker) handleFlagMessages(msg *types.FlagMessages) error {
 	for _, uid := range msg.Uids {
 		m, err := w.c.Message(*w.selected, uid)
@@ -880,7 +903,7 @@ func (w *Worker) handleSearchDirectory(msg *types.SearchDirectory) error {
 	return nil
 }
 
-func (w *Worker) msgInfoFromUid(uid uint32) (*models.MessageInfo, error) {
+func (w *Worker) msgInfoFromUid(uid models.UID) (*models.MessageInfo, error) {
 	m, err := w.c.Message(*w.selected, uid)
 	if err != nil {
 		return nil, err
@@ -900,7 +923,7 @@ func (w *Worker) msgInfoFromUid(uid uint32) (*models.MessageInfo, error) {
 	return info, nil
 }
 
-func (w *Worker) msgHeadersFromUid(uid uint32) (*models.MessageInfo, error) {
+func (w *Worker) msgHeadersFromUid(uid models.UID) (*models.MessageInfo, error) {
 	m, err := w.c.Message(*w.selected, uid)
 	if err != nil {
 		return nil, err
